@@ -25,15 +25,12 @@ const Clutter = imports.gi.Clutter;
 const Gdk = imports.gi.Gdk;
 const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const MapWalker = imports.mapWalker;
 const Utils = imports.utils;
 
-var MapMarker = new Lang.Class({
-    Name: 'MapMarker',
-    Extends: Champlain.Marker,
+var MapMarker = GObject.registerClass({
     Implements: [Champlain.Exportable],
     Abstract: true,
     Signals: {
@@ -42,9 +39,10 @@ var MapMarker = new Lang.Class({
     Properties: {
         'surface': GObject.ParamSpec.override('surface',
                                               Champlain.Exportable)
-    },
+    }
+}, class MapMarker extends Champlain.Marker {
 
-    _init: function(params) {
+    _init(params) {
         this._place = params.place;
         delete params.place;
 
@@ -55,7 +53,7 @@ var MapMarker = new Lang.Class({
         params.longitude = this.place.location.longitude;
         params.selectable = true;
 
-        this.parent(params);
+        super._init(params);
 
         this.connect('notify::size', this._translateMarkerPosition.bind(this));
         if (this._mapView) {
@@ -76,25 +74,25 @@ var MapMarker = new Lang.Class({
             this._view.connect('notify::longitude', this._onViewUpdated.bind(this));
             this._view.connect('notify::zoom-level', this._onViewUpdated.bind(this));
         }
-    },
+    }
 
     get surface() {
         return this._surface;
-    },
+    }
 
     set surface(v) {
         this._surface = v;
-    },
+    }
 
-    vfunc_get_surface: function() {
+    vfunc_get_surface() {
         return this._surface;
-    },
+    }
 
-    vfunc_set_surface: function(surface) {
+    vfunc_set_surface(surface) {
         this._surface = surface;
-    },
+    }
 
-    _actorFromIconName: function(name, size, color) {
+    _actorFromIconName(name, size, color) {
         try {
             let theme = Gtk.IconTheme.get_default();
             let pixbuf;
@@ -109,7 +107,7 @@ var MapMarker = new Lang.Class({
             let canvas = new Clutter.Canvas({ width: pixbuf.get_width(),
                                               height: pixbuf.get_height() });
 
-            canvas.connect('draw', (function(canvas, cr) {
+            canvas.connect('draw', (canvas, cr) => {
                 cr.setOperator(Cairo.Operator.CLEAR);
                 cr.paint();
                 cr.setOperator(Cairo.Operator.OVER);
@@ -118,7 +116,7 @@ var MapMarker = new Lang.Class({
                 cr.paint();
 
                 this._surface = cr.getTarget();
-            }).bind(this));
+            });
 
             let actor = new Clutter.Actor();
             actor.set_content(canvas);
@@ -130,9 +128,9 @@ var MapMarker = new Lang.Class({
             Utils.debug('Failed to load image: %s'.format(e.message));
             return null;
         }
-    },
+    }
 
-    _onButtonPress: function(marker, event) {
+    _onButtonPress(marker, event) {
         // Zoom in on marker on double-click
         if (event.get_click_count() > 1) {
             if (this._view.zoom_level < this._view.max_zoom_level) {
@@ -140,11 +138,11 @@ var MapMarker = new Lang.Class({
                 this._view.center_on(this.latitude, this.longitude);
             }
         }
-    },
+    }
 
-    _translateMarkerPosition: function() {
+    _translateMarkerPosition() {
         this.set_translation(-this.anchor.x, -this.anchor.y, 0);
-    },
+    }
 
     /**
      * Returns: The anchor point for the marker icon, relative to the
@@ -152,29 +150,29 @@ var MapMarker = new Lang.Class({
      */
     get anchor() {
         return { x: 0, y: 0 };
-    },
+    }
 
     get bubbleSpacing() {
         return 0;
-    },
+    }
 
     get place() {
         return this._place;
-    },
+    }
 
     get bubble() {
         if (this._bubble === undefined)
             this._bubble = this._createBubble();
 
         return this._bubble;
-    },
+    }
 
-    _createBubble: function() {
+    _createBubble() {
         // Markers has no associated bubble by default
         return null;
-    },
+    }
 
-    _positionBubble: function(bubble) {
+    _positionBubble(bubble) {
         let [tx, ty, tz] = this.get_translation();
         let x = this._view.longitude_to_x(this.longitude);
         let y = this._view.latitude_to_y(this.latitude);
@@ -200,11 +198,11 @@ var MapMarker = new Lang.Class({
         // Avoid bubble to cover header bar if the marker is close to the top map edge
         else if (pos.y - bubbleSize.height <= 0)
             bubble.position = Gtk.PositionType.BOTTOM;
-    },
+    }
 
-    _hideBubbleOn: function(signal, duration) {
+    _hideBubbleOn(signal, duration) {
         let sourceId = null;
-        let signalId = this._view.connect(signal, (function() {
+        let signalId = this._view.connect(signal, () => {
             if (sourceId)
                 Mainloop.source_remove(sourceId);
             else
@@ -219,26 +217,26 @@ var MapMarker = new Lang.Class({
                 sourceId = Mainloop.timeout_add(duration, callback);
             else
                 sourceId = Mainloop.idle_add(callback);
-        }).bind(this));
+        });
 
-        Utils.once(this.bubble, 'closed', (function() {
+        Utils.once(this.bubble, 'closed', () => {
             // We still listening for the signal to refresh
             // the existent timeout
             if (!sourceId)
                 this._view.disconnect(signalId);
-        }).bind(this));
+        });
 
-        Utils.once(this, 'notify::selected', (function() {
+        Utils.once(this, 'notify::selected', () => {
             // When the marker gets deselected, we need to ensure
             // that the timeout callback is not called anymore.
             if (sourceId) {
                 Mainloop.source_remove(sourceId);
                 this._view.disconnect(signalId);
             }
-        }).bind(this));
-    },
+        });
+    }
 
-    _initBubbleSignals: function() {
+    _initBubbleSignals() {
         this._hideBubbleOn('notify::zoom-level', 500);
         this._hideBubbleOn('notify::size');
 
@@ -249,26 +247,26 @@ var MapMarker = new Lang.Class({
         // does the job.
         this._mapView.onSetMarkerSelected(this);
 
-        let markerSelectedSignalId = this._mapView.connect('marker-selected', (function(mapView, selectedMarker) {
+        let markerSelectedSignalId = this._mapView.connect('marker-selected', (mapView, selectedMarker) => {
             if (this.get_parent() !== selectedMarker.get_parent())
                 this.selected = false;
-        }).bind(this));
+        });
 
-        let goingToSignalId = this._mapView.connect('going-to', (function() {
+        let goingToSignalId = this._mapView.connect('going-to', () => {
             this.set_selected(false);
-        }).bind(this));
+        });
         let buttonPressSignalId =
-            this._view.connect('button-press-event', (function() {
+            this._view.connect('button-press-event', () => {
                 this.set_selected(false);
-            }).bind(this));
+            });
         // Destroy the bubble when the marker is destroyed o removed from a layer
-        let parentSetSignalId = this.connect('parent-set', (function() {
+        let parentSetSignalId = this.connect('parent-set', () => {
             this.set_selected(false);
-        }).bind(this));
-        let dragMotionSignalId = this.connect('drag-motion', (function() {
+        });
+        let dragMotionSignalId = this.connect('drag-motion', () => {
             this.set_selected(false);
-        }).bind(this));
-        Utils.once(this.bubble, 'closed', (function() {
+        });
+        Utils.once(this.bubble, 'closed', () => {
             this._mapView.disconnect(markerSelectedSignalId);
             this._mapView.disconnect(goingToSignalId);
             this._view.disconnect(buttonPressSignalId);
@@ -277,10 +275,10 @@ var MapMarker = new Lang.Class({
 
             this._bubble.destroy();
             delete this._bubble;
-        }).bind(this));
-    },
+        });
+    }
 
-    _isInsideView: function() {
+    _isInsideView() {
         let [tx, ty, tz] = this.get_translation();
         let x = this._view.longitude_to_x(this.longitude);
         let y = this._view.latitude_to_y(this.latitude);
@@ -288,58 +286,53 @@ var MapMarker = new Lang.Class({
 
         return x + tx + this.width > 0 && x + tx < mapSize.width &&
                y + ty + this.height > 0 && y + ty < mapSize.height;
-    },
+    }
 
-    _onViewUpdated: function() {
+    _onViewUpdated() {
         if (this.bubble) {
             if (this._isInsideView())
                 this._positionBubble(this.bubble);
             else
                 this.bubble.hide();
         }
-    },
+    }
 
-    showBubble: function() {
+    showBubble() {
         if (this.bubble && !this.bubble.visible && this._isInsideView()) {
             this._initBubbleSignals();
             this.bubble.show();
             this._positionBubble(this.bubble);
         }
-    },
+    }
 
-    hideBubble: function() {
+    hideBubble() {
         if (this._bubble)
             this._bubble.hide();
-    },
+    }
 
     get walker() {
         if (this._walker === undefined)
             this._walker = new MapWalker.MapWalker(this.place, this._mapView);
 
         return this._walker;
-    },
+    }
 
-    zoomToFit: function() {
+    zoomToFit() {
         this.walker.zoomToFit();
-    },
-
-    goTo: function(animate) {
-        Utils.once(this.walker, 'gone-to', (function() {
-            this.emit('gone-to');
-        }).bind(this));
+    }
 
+    goTo(animate) {
+        Utils.once(this.walker, 'gone-to', () => this.emit('gone-to'));
         this.walker.goTo(animate);
-    },
+    }
 
-    goToAndSelect: function(animate) {
-        Utils.once(this, 'gone-to', (function() {
-            this.selected = true;
-        }).bind(this));
+    goToAndSelect(animate) {
+        Utils.once(this, 'gone-to', () => this.selected = true);
 
         this.goTo(animate);
-    },
+    }
 
-    _onMarkerSelected: function() {
+    _onMarkerSelected() {
         if (this.selected)
             this.showBubble();
         else
