@@ -25,7 +25,6 @@ const GObject = imports.gi.GObject;
 const Geocode = imports.gi.GeocodeGlib;
 const Gio = imports.gi.Gio;
 const GtkChamplain = imports.gi.GtkChamplain;
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
@@ -86,9 +85,7 @@ const DASHED_ROUTE_LINE_FILLED_LENGTH = 5;
 // length of gaps of dashed lines used for walking legs of transit itineraries
 const DASHED_ROUTE_LINE_GAP_LENGTH = 5;
 
-var MapView = new Lang.Class({
-    Name: 'MapView',
-    Extends: GtkChamplain.Embed,
+var MapView = GObject.registerClass({
     Properties: {
         // this property is true when the routing sidebar is active
         'routingOpen': GObject.ParamSpec.boolean('routingOpen',
@@ -113,35 +110,34 @@ var MapView = new Lang.Class({
         'view-moved': {},
         'marker-selected': { param_types: [Champlain.Marker] }
     },
+}, class MapView extends GtkChamplain.Embed {
 
     get routingOpen() {
         return this._routingOpen || this._instructionMarkerLayer.visible;
-    },
+    }
 
     set routingOpen(value) {
         let isValid = Application.routeQuery.isValid();
 
         this._routingOpen = value && isValid;
-        this._routeLayers.forEach((function(routeLayer) {
-            routeLayer.visible = value && isValid;
-        }).bind(this));
+        this._routeLayers.forEach((routeLayer) => routeLayer.visible = value && isValid);
         this._instructionMarkerLayer.visible = value && isValid;
         if (!value)
             this.routeShowing = false;
         this.notify('routingOpen');
-    },
+    }
 
     get routeShowing() {
         return this._routeShowing;
-    },
+    }
 
     set routeShowing(value) {
         this._routeShowing = value;
         this.notify('routeShowing');
-    },
+    }
 
-    _init: function(params) {
-        this.parent();
+    _init(params) {
+        super._init();
 
         let mapType = params.mapType || MapType.STREET;
         delete params.mapType;
@@ -153,16 +149,15 @@ var MapView = new Lang.Class({
 
         this.shapeLayerStore = new Gio.ListStore(GObject.TYPE_OBJECT);
 
-        this._updateUserLocation();
         Application.geoclue.connect('location-changed',
                                     this._updateUserLocation.bind(this));
         Application.geoclue.connect('notify::state',
                                     this._updateUserLocation.bind(this));
         this._storeId = 0;
         this._connectRouteSignals();
-    },
+    }
 
-    _initScale: function(view) {
+    _initScale(view) {
         this._scale = new Champlain.Scale({ visible: true });
         this._scale.connect_view(view);
 
@@ -176,9 +171,9 @@ var MapView = new Lang.Class({
         this._scale.set_x_align(Clutter.ActorAlign.START);
         this._scale.set_y_align(Clutter.ActorAlign.END);
         view.add_child(this._scale);
-    },
+    }
 
-    _initView: function() {
+    _initView() {
         let view = this.get_view();
         view.zoom_level = 3;
         view.min_zoom_level = MapMinZoom;
@@ -191,18 +186,18 @@ var MapView = new Lang.Class({
             view.connect('notify::realized', this._goToStoredLocation.bind(this));
         view.connect('notify::latitude', this._onViewMoved.bind(this));
         // switching map type will set view min-zoom-level from map source
-        view.connect('notify::min-zoom-level', (function() {
+        view.connect('notify::min-zoom-level', () => {
             if (view.min_zoom_level < MapMinZoom) {
                 view.min_zoom_level = MapMinZoom;
             }
-        }).bind(this));
+        });
 
         this._initScale(view);
         return view;
-    },
+    }
 
     /* create and store a route layer, pass true to get a dashed line */
-    _createRouteLayer: function(dashed, lineColor, width) {
+    _createRouteLayer(dashed, lineColor, width) {
         let red = Color.parseColor(lineColor, 0);
         let green = Color.parseColor(lineColor, 1);
         let blue = Color.parseColor(lineColor, 2);
@@ -221,19 +216,19 @@ var MapView = new Lang.Class({
         this.view.add_layer(routeLayer);
 
         return routeLayer;
-    },
+    }
 
-    _clearRouteLayers: function() {
-        this._routeLayers.forEach((function(routeLayer) {
+    _clearRouteLayers() {
+        this._routeLayers.forEach((routeLayer) => {
             routeLayer.remove_all();
             routeLayer.visible = false;
             this.view.remove_layer(routeLayer);
-        }).bind(this));
+        });
 
         this._routeLayers = [];
-    },
+    }
 
-    _initLayers: function() {
+    _initLayers() {
         let mode = Champlain.SelectionMode.SINGLE;
 
         this._userLocationLayer = new Champlain.MarkerLayer({ selection_mode: mode });
@@ -253,49 +248,47 @@ var MapView = new Lang.Class({
         ShapeLayer.SUPPORTED_TYPES.push(GpxShapeLayer.GpxShapeLayer);
 
         this._routeLayers = [];
-    },
+    }
 
-    _ensureInstructionLayerAboveRouteLayers: function() {
+    _ensureInstructionLayerAboveRouteLayers() {
         this.view.remove_layer(this._instructionMarkerLayer);
         this.view.add_layer(this._instructionMarkerLayer);
-    },
+    }
 
-    _connectRouteSignals: function() {
+    _connectRouteSignals() {
         let route = Application.routingDelegator.graphHopper.route;
         let transitPlan = Application.routingDelegator.openTripPlanner.plan;
         let query = Application.routeQuery;
 
-        route.connect('update', (function() {
+        route.connect('update', () => {
             this.showRoute(route);
             this.routeShowing = true;
-        }).bind(this));
-        route.connect('reset', (function() {
+        });
+        route.connect('reset', () => {
             this._clearRouteLayers();
             this._instructionMarkerLayer.remove_all();
             this.routeShowing = false;
-        }).bind(this));
-        transitPlan.connect('update', this._showTransitPlan.bind(this, transitPlan));
-        transitPlan.connect('reset', (function() {
+        });
+        transitPlan.connect('update', () => this._showTransitPlan(transitPlan));
+        transitPlan.connect('reset', () => {
             this._clearRouteLayers();
             this._instructionMarkerLayer.remove_all();
             this.routeShowing = false;
-        }).bind(this));
-        transitPlan.connect('itinerary-selected', (function(obj, itinerary) {
+        });
+        transitPlan.connect('itinerary-selected', (obj, itinerary) => {
             this._showTransitItinerary(itinerary);
             this.routeShowing = true;
-        }).bind(this));
-        transitPlan.connect('itinerary-deselected', (function() {
+        });
+        transitPlan.connect('itinerary-deselected', () => {
             this._clearRouteLayers();
             this._instructionMarkerLayer.remove_all();
             this.routeShowing = false;
-        }).bind(this));
+        });
 
-        query.connect('notify', (function() {
-                this.routingOpen = query.isValid();
-        }).bind(this));
-    },
+        query.connect('notify', () => this.routingOpen = query.isValid());
+    }
 
-    setMapType: function(mapType) {
+    setMapType(mapType) {
         if (this._mapType && this._mapType === mapType)
             return;
 
@@ -334,19 +327,17 @@ var MapView = new Lang.Class({
             }
         }
 
-        overlay_sources.forEach((function(source) {
-            this.view.add_overlay_source(source, 255);
-        }).bind(this));
-    },
+        overlay_sources.forEach((source) => this.view.add_overlay_source(source, 255));
+    }
 
-    toggleScale: function() {
+    toggleScale() {
         this._scale.visible = !this._scale.visible;
-    },
+    }
 
-    openShapeLayers: function(files) {
+    openShapeLayers(files) {
         let bbox = new Champlain.BoundingBox();
         let ret = true;
-        files.forEach((function(file){
+        files.forEach((file) => {
             try {
                 let i = this._findShapeLayerIndex(file);
                 let layer = (i > -1) ? this.shapeLayerStore.get_item(i) : null;
@@ -364,26 +355,26 @@ var MapView = new Lang.Class({
                 Application.notificationManager.showMessage(msg);
                 ret = false;
             }
-        }).bind(this));
+        });
 
         this.gotoBBox(bbox);
         return ret;
-    },
+    }
 
-    removeShapeLayer: function(shapeLayer) {
+    removeShapeLayer(shapeLayer) {
         shapeLayer.unload();
         let i = this._findShapeLayerIndex(shapeLayer.file);
         this.shapeLayerStore.remove(i);
-    },
+    }
 
-    _findShapeLayerIndex: function(file) {
+    _findShapeLayerIndex(file) {
         for (let i = 0; i < this.shapeLayerStore.get_n_items(); i++)
             if (this.shapeLayerStore.get_item(i).file.equal(file))
                 return i;
         return -1;
-    },
+    }
 
-    goToGeoURI: function(uri) {
+    goToGeoURI(uri) {
         try {
             let location = new Location.Location({ heading: -1 });
             location.set_from_uri(uri);
@@ -400,26 +391,25 @@ var MapView = new Lang.Class({
             Application.notificationManager.showMessage(msg);
             Utils.debug("failed to open GeoURI: %s".format(e.message));
         }
-    },
+    }
 
-    gotoUserLocation: function(animate) {
+    gotoUserLocation(animate) {
         if (!this._userLocation)
             return;
 
         this.emit('going-to-user-location');
-        Utils.once(this._userLocation, "gone-to", (function() {
-            this.emit('gone-to-user-location');
-        }).bind(this));
+        Utils.once(this._userLocation, "gone-to",
+                   () => this.emit('gone-to-user-location'));
         this._userLocation.goTo(animate);
-    },
+    }
 
-    userLocationVisible: function() {
+    userLocationVisible() {
         let box = this.view.get_bounding_box();
 
         return box.covers(this._userLocation.latitude, this._userLocation.longitude);
-    },
+    }
 
-    _updateUserLocation: function() {
+    _updateUserLocation() {
         if (!Application.geoclue.place)
             return;
 
@@ -443,15 +433,15 @@ var MapView = new Lang.Class({
         this._userLocation.selected = previousSelected;
 
         this.emit('user-location-changed');
-    },
+    }
 
-    _storeLocation: function() {
+    _storeLocation() {
         let box = this.view.get_bounding_box();
         let lastViewedLocation = [box.top, box.bottom, box.left, box.right];
         Application.settings.set('last-viewed-location', lastViewedLocation);
-    },
+    }
 
-    _goToStoredLocation: function() {
+    _goToStoredLocation() {
         if (!this.view.realized)
             return;
 
@@ -461,9 +451,9 @@ var MapView = new Lang.Class({
                                                        left: box[2],
                                                        right: box[3] });
         this.gotoBBox(bounding_box, true);
-    },
+    }
 
-    gotoBBox: function(bbox, linear) {
+    gotoBBox(bbox, linear) {
         if (!bbox.is_valid()) {
             Utils.debug('Bounding box is invalid');
             return;
@@ -479,9 +469,9 @@ var MapView = new Lang.Class({
                                                     right  : bbox.right })
         });
         new MapWalker.MapWalker(place, this).goTo(true, linear);
-    },
+    }
 
-    showTurnPoint: function(turnPoint) {
+    showTurnPoint(turnPoint) {
         if (this._turnPointMarker)
             this._turnPointMarker.destroy();
 
@@ -492,9 +482,9 @@ var MapView = new Lang.Class({
                                                                       mapView: this });
         this._instructionMarkerLayer.add_marker(this._turnPointMarker);
         this._turnPointMarker.goTo();
-    },
+    }
 
-    showTransitStop: function(transitStop, transitLeg) {
+    showTransitStop(transitStop, transitLeg) {
         if (this._turnPointMarker)
             this._turnPointMarker.destroy();
 
@@ -503,29 +493,29 @@ var MapView = new Lang.Class({
                                                                       mapView: this });
         this._instructionMarkerLayer.add_marker(this._turnPointMarker);
         this._turnPointMarker.goTo();
-    },
+    }
 
-    showContact: function(contact) {
+    showContact(contact) {
         let places = contact.get_places();
         if (places.length === 0)
             return;
 
         this._placeLayer.remove_all();
-        places.forEach((function(p) {
+        places.forEach((p) => {
             let place = new ContactPlace.ContactPlace({ place: p,
                                                         contact: contact });
             let marker = new PlaceMarker.PlaceMarker({ place: place,
                                                        mapView: this });
             this._placeLayer.add_marker(marker);
-        }).bind(this));
+        });
 
         if (places.length > 1)
             this.gotoBBox(contact.bounding_box);
         else
             new MapWalker.MapWalker(places[0], this).goTo(true);
-    },
+    }
 
-    _showStoredRoute: function(stored) {
+    _showStoredRoute(stored) {
         let query = Application.routeQuery;
         let route = Application.routingDelegator.graphHopper.route;
 
@@ -548,9 +538,9 @@ var MapView = new Lang.Class({
             query.thaw_notify();
         });
         route.reset();
-    },
+    }
 
-    showPlace: function(place, animation) {
+    showPlace(place, animation) {
         this._placeLayer.remove_all();
 
         if (place instanceof StoredRoute.StoredRoute) {
@@ -564,9 +554,9 @@ var MapView = new Lang.Class({
 
         this._placeLayer.add_marker(placeMarker);
         placeMarker.goToAndSelect(animation);
-    },
+    }
 
-    showRoute: function(route) {
+    showRoute(route) {
         let routeLayer;
 
         this._clearRouteLayers();
@@ -574,24 +564,22 @@ var MapView = new Lang.Class({
 
         routeLayer = this._createRouteLayer(false, TURN_BY_TURN_ROUTE_COLOR,
                                             ROUTE_LINE_WIDTH);
-        route.path.forEach((function (polyline) {
-            routeLayer.add_node(polyline);
-        }).bind(this));
+        route.path.forEach((polyline) => routeLayer.add_node(polyline));
         this.routingOpen = true;
 
         this._ensureInstructionLayerAboveRouteLayers();
 
         this._showDestinationTurnpoints();
         this.gotoBBox(route.bbox);
-    },
+    }
 
-    _showDestinationTurnpoints: function() {
+    _showDestinationTurnpoints() {
         let route = Application.routingDelegator.graphHopper.route;
         let query = Application.routeQuery;
         let pointIndex = 0;
 
         this._instructionMarkerLayer.remove_all();
-        route.turnPoints.forEach(function(turnPoint) {
+        route.turnPoints.forEach((turnPoint) => {
             if (turnPoint.isStop()) {
                 let queryPoint = query.filledPoints[pointIndex];
                 let destinationMarker = new TurnPointMarker.TurnPointMarker({ turnPoint: turnPoint,
@@ -601,15 +589,15 @@ var MapView = new Lang.Class({
                 pointIndex++;
             }
         }, this);
-    },
+    }
 
-    _showTransitItinerary: function(itinerary) {
+    _showTransitItinerary(itinerary) {
         this.gotoBBox(itinerary.bbox);
         this._clearRouteLayers();
         this._placeLayer.remove_all();
         this._instructionMarkerLayer.remove_all();
 
-        itinerary.legs.forEach((function (leg, index) {
+        itinerary.legs.forEach((leg, index) => {
             let dashed = !leg.transit;
             let color = leg.color;
             let outlineColor = leg.textColor;
@@ -653,11 +641,11 @@ var MapView = new Lang.Class({
 
                 routeLayer.add_node(firstPoint);
             }
-        }).bind(this));
+        });
 
         this._ensureInstructionLayerAboveRouteLayers();
 
-        itinerary.legs.forEach((function (leg, index) {
+        itinerary.legs.forEach((leg, index) => {
             let previousLeg = index === 0 ? null : itinerary.legs[index - 1];
 
             /* add start marker */
@@ -672,7 +660,7 @@ var MapView = new Lang.Class({
             }
 
             this._instructionMarkerLayer.add_marker(start);
-        }).bind(this));
+        });
 
         /* add arrival marker */
         let lastLeg = itinerary.legs.last();
@@ -681,24 +669,24 @@ var MapView = new Lang.Class({
         this._instructionMarkerLayer.add_marker(arrival);
 
         this.routingOpen = true;
-    },
+    }
 
-    _showTransitPlan: function(plan) {
+    _showTransitPlan(plan) {
         this.gotoBBox(plan.bbox);
-    },
+    }
 
-    _onViewMoved: function() {
+    _onViewMoved() {
         this.emit('view-moved');
         if (this._storeId !== 0)
             return;
 
-        this._storeId = Mainloop.timeout_add(_LOCATION_STORE_TIMEOUT,(function(){
+        this._storeId = Mainloop.timeout_add(_LOCATION_STORE_TIMEOUT, () => {
             this._storeId = 0;
             this._storeLocation();
-        }).bind(this));
-    },
+        });
+    }
 
-    onSetMarkerSelected: function(selectedMarker) {
+    onSetMarkerSelected(selectedMarker) {
         this.emit('marker-selected', selectedMarker);
     }
 });
