@@ -25,8 +25,8 @@ const _ = imports.gettext.gettext;
 const Geocode = imports.gi.GeocodeGlib;
 const Gio = imports.gi.Gio;
 const GLib = imports.gi.GLib;
+const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
-const Lang = imports.lang;
 const Soup = imports.gi.Soup;
 
 const Application = imports.application;
@@ -220,16 +220,15 @@ const OSM_FIELDS = [
         hint: _("Information used to inform other mappers about non-obvious information about an element, the author’s intent when creating it, or hints for further improvement.")
     }];
 
-const OSMEditAddress = new Lang.Class({
-    Name: 'OSMEditAddress',
-    Extends: Gtk.Grid,
+const OSMEditAddress = GObject.registerClass({
     Template: 'resource:///org/gnome/Maps/ui/osm-edit-address.ui',
     Children: [ 'street',
                 'number',
                 'post',
                 'city' ],
+}, class OSMEditAddress extends Gtk.Grid {
 
-    _init: function(params) {
+    _init(params) {
         let street = params.street;
         delete params.street;
 
@@ -242,7 +241,7 @@ const OSMEditAddress = new Lang.Class({
         let city = params.city;
         delete params.city;
 
-        this.parent(params);
+        super._init(params);
 
         if (street)
             this.street.text = street;
@@ -259,9 +258,7 @@ const OSMEditAddress = new Lang.Class({
 });
 
 
-var OSMEditDialog = new Lang.Class({
-    Name: 'OSMEditDialog',
-    Extends: Gtk.Dialog,
+var OSMEditDialog = GObject.registerClass({
     Template: 'resource:///org/gnome/Maps/ui/osm-edit-dialog.ui',
     InternalChildren: [ 'cancelButton',
                         'backButton',
@@ -280,8 +277,9 @@ var OSMEditDialog = new Lang.Class({
                         'hintPopover',
                         'hintLabel',
                         'headerBar'],
+}, class OSMEditDialog extends Gtk.Dialog {
 
-    _init: function(params) {
+    _init(params) {
         this._place = params.place;
         delete params.place;
 
@@ -297,7 +295,7 @@ var OSMEditDialog = new Lang.Class({
         /* This is a construct-only property and cannot be set by GtkBuilder */
         params.use_header_bar = true;
 
-        this.parent(params);
+        super._init(params);
 
         /* I could not get this widget working from within the widget template
          * this results in a segfault. The widget definition is left in-place,
@@ -308,22 +306,18 @@ var OSMEditDialog = new Lang.Class({
         this._typeSearch.can_focus = true;
 
         let typeSearchPopover = this._typeSearch.popover;
-        typeSearchPopover.connect('selected', this._onTypeSelected.bind(this));
+        typeSearchPopover.connect('selected', () => this._onTypeSelected());
 
         this._cancellable = new Gio.Cancellable();
-        this._cancellable.connect((function() {
-            this.response(Response.CANCELLED);
-        }).bind(this));
+        this._cancellable.connect(() => this.response(Response.CANCELLED));
 
-        this.connect('delete-event', (function() {
-            this._cancellable.cancel();
-        }).bind(this));
+        this.connect('delete-event', () => this._cancellable.cancel());
 
         this._isEditing = false;
-        this._nextButton.connect('clicked', this._onNextClicked.bind(this));
-        this._cancelButton.connect('clicked', this._onCancelClicked.bind(this));
-        this._backButton.connect('clicked', this._onBackClicked.bind(this));
-        this._typeButton.connect('clicked', this._onTypeClicked.bind(this));
+        this._nextButton.connect('clicked', () => this._onNextClicked());
+        this._cancelButton.connect('clicked', () => this._onCancelClicked());
+        this._backButton.connect('clicked', () => this._onBackClicked());
+        this._typeButton.connect('clicked', () => this._onTypeClicked());
 
         if (this._addLocation) {
             this._headerBar.title = C_("dialog title", "Add to OpenStreetMap");
@@ -351,17 +345,17 @@ var OSMEditDialog = new Lang.Class({
         this._originalTitle = this._headerBar.title;
         this._updateRecentTypesList();
 
-        this._recentTypesListBox.set_header_func(function (row, previous) {
+        this._recentTypesListBox.set_header_func((row, previous) => {
             if (previous)
                 row.set_header(new Gtk.Separator());
         });
 
-        this._recentTypesListBox.connect('row-activated', (function(listbox, row) {
+        this._recentTypesListBox.connect('row-activated', (listbox, row) => {
             this._onTypeSelected(null, row._key, row._value, row._title);
-        }).bind(this));
-    },
+        });
+    }
 
-    _onNextClicked: function() {
+    _onNextClicked() {
         if (this._isEditing) {
             this._switchToUpload();
         } else {
@@ -374,17 +368,17 @@ var OSMEditDialog = new Lang.Class({
                                              this._osmType, comment,
                                              this._onObjectUploaded.bind(this));
         }
-    },
+    }
 
-    _onTypeClicked: function() {
+    _onTypeClicked() {
         this._cancelButton.visible = false;
         this._backButton.visible = true;
         this._nextButton.visible = false;
         this._headerBar.title = _("Select Type");
         this._stack.visible_child_name = 'select-type';
-    },
+    }
 
-    _onTypeSelected: function(popover, key, value, title) {
+    _onTypeSelected(popover, key, value, title) {
         this._typeValueLabel.label = title;
         this._updateType(key, value);
 
@@ -409,20 +403,18 @@ var OSMEditDialog = new Lang.Class({
         this._nextButton.sensitive = true;
 
         this._updateRecentTypesList();
-    },
+    }
 
-    _updateType: function(key, value) {
+    _updateType(key, value) {
         /* clear out any previous type-related OSM tags */
-        OSMTypes.OSM_TYPE_TAGS.forEach((function (tag) {
-            this._osmObject.delete_tag(tag);
-        }).bind(this));
+        OSMTypes.OSM_TYPE_TAGS.forEach((tag) => this._osmObject.delete_tag(tag));
 
         this._osmObject.set_tag(key, value);
-    },
+    }
 
     /* update visibility and enable the type selection button if the object has
      * a well-known type (based on a known set of tags) */
-    _updateTypeButton: function() {
+    _updateTypeButton() {
         let numTypeTags = 0;
         let lastTypeTag = null;
 
@@ -453,9 +445,9 @@ var OSMEditDialog = new Lang.Class({
                 this._typeButton.visible = true;
             }
         }
-    },
+    }
 
-    _updateRecentTypesList: function() {
+    _updateRecentTypesList() {
         let recentTypes = OSMTypes.recentTypesStore.recentTypes;
 
         if (recentTypes.length > 0) {
@@ -495,9 +487,9 @@ var OSMEditDialog = new Lang.Class({
             this._recentTypesLabel.visible = false;
             this._recentTypesListBox.visible = false;
         }
-    },
+    }
 
-    _switchToUpload: function() {
+    _switchToUpload() {
         this._stack.set_visible_child_name('upload');
         this._nextButton.label = _("Done");
         this._cancelButton.visible = false;
@@ -505,13 +497,13 @@ var OSMEditDialog = new Lang.Class({
         this._cancelButton.visible = false;
         this._isEditing = false;
         this._commentTextView.grab_focus();
-    },
+    }
 
-    _onCancelClicked: function() {
+    _onCancelClicked() {
         this.response(Response.CANCELLED);
-    },
+    }
 
-    _onBackClicked: function() {
+    _onBackClicked() {
         this._backButton.visible = false;
         this._cancelButton.visible = true;
         this._nextButton.visible = true;
@@ -521,27 +513,27 @@ var OSMEditDialog = new Lang.Class({
         this._commentTextView.buffer.text = '';
         this._typeSearch.text = '';
         this._headerBar.title = this._originalTitle;
-    },
+    }
 
-    _onObjectFetched: function(success, status, osmObject, osmType, error) {
+    _onObjectFetched(success, status, osmObject, osmType, error) {
         if (success) {
             this._isEditing = true;
             this._loadOSMData(osmObject);
         } else {
             this._showError(status, error);
         }
-    },
+    }
 
-    _onObjectUploaded: function(success, status) {
+    _onObjectUploaded(success, status) {
         if (success) {
             this.response(Response.UPLOADED);
         } else {
             this._showError(status);
             this.response(Response.ERROR);
         }
-    },
+    }
 
-    _showError: function(status, error) {
+    _showError(status, error) {
         /* set error message from specific error if available, otherwise use
          * a generic error message for the HTTP status code */
         let statusMessage =
@@ -558,10 +550,10 @@ var OSMEditDialog = new Lang.Class({
         messageDialog.run();
         messageDialog.destroy();
         this.response(Response.ERROR);
-    },
+    }
 
     /* GtkContainer.child_get_property doesn't seem to be usable from GJS */
-    _getRowOfDeleteButton: function(button) {
+    _getRowOfDeleteButton(button) {
         for (let row = 1; row < this._currentRow; row++) {
             let label = this._editorGrid.get_child_at(0, row);
             let deleteButton = this._editorGrid.get_child_at(2, row);
@@ -571,9 +563,9 @@ var OSMEditDialog = new Lang.Class({
         }
 
         return -1;
-    },
+    }
 
-    _addOSMEditDeleteButton: function(fieldSpec) {
+    _addOSMEditDeleteButton(fieldSpec) {
         let deleteButton = Gtk.Button.new_from_icon_name('user-trash-symbolic',
                                                          Gtk.IconSize.BUTTON);
         let styleContext = deleteButton.get_style_context();
@@ -582,11 +574,9 @@ var OSMEditDialog = new Lang.Class({
         styleContext.add_class('flat');
         this._editorGrid.attach(deleteButton, 2, this._currentRow, 1, 1);
 
-        deleteButton.connect('clicked', (function() {
+        deleteButton.connect('clicked', () => {
             if (fieldSpec.subtags) {
-                fieldSpec.subtags.forEach((function(key) {
-                    this._osmObject.delete_tag(key);
-                }).bind(this));
+                fieldSpec.subtags.forEach((key) => this._osmObject.delete_tag(key));
             } else {
                 this._osmObject.delete_tag(fieldSpec.tag);
             }
@@ -598,12 +588,12 @@ var OSMEditDialog = new Lang.Class({
             }
             this._nextButton.sensitive = true;
             this._updateAddFieldMenu();
-        }).bind(this));
+        });
 
         deleteButton.show();
-    },
+    }
 
-    _addOSMEditLabel: function(fieldSpec) {
+    _addOSMEditLabel(fieldSpec) {
         let text = fieldSpec.name;
         if (fieldSpec.includeHelp) {
             let link = _WIKI_BASE + fieldSpec.tag;
@@ -615,9 +605,9 @@ var OSMEditDialog = new Lang.Class({
         label.get_style_context().add_class('dim-label');
         this._editorGrid.attach(label, 0, this._currentRow, 1, 1);
         label.show();
-    },
+    }
 
-    _showHintPopover: function(entry, hint) {
+    _showHintPopover(entry, hint) {
         if (this._hintPopover.visible) {
             this._hintPopover.popdown();
         } else {
@@ -625,9 +615,9 @@ var OSMEditDialog = new Lang.Class({
             this._hintLabel.label = hint;
             this._hintPopover.popup();
         }
-    },
+    }
 
-    _addOSMEditTextEntry: function(fieldSpec, value) {
+    _addOSMEditTextEntry(fieldSpec, value) {
         this._addOSMEditLabel(fieldSpec);
 
         let entry = new Gtk.Entry();
@@ -636,18 +626,18 @@ var OSMEditDialog = new Lang.Class({
         if (fieldSpec.placeHolder)
             entry.placeholder_text = fieldSpec.placeHolder;
 
-        entry.connect('changed', (function() {
+        entry.connect('changed', () => {
             if (fieldSpec.rewriteFunc)
                 entry.text = fieldSpec.rewriteFunc(entry.text);
             this._osmObject.set_tag(fieldSpec.tag, entry.text);
             this._nextButton.sensitive = true;
-        }).bind(this));
+        });
 
         if (fieldSpec.hint) {
             entry.secondary_icon_name = 'dialog-information-symbolic';
-            entry.connect('icon-press', (function(entry, iconPos, event) {
+            entry.connect('icon-press', (entry, iconPos, event) => {
                 this._showHintPopover(entry, fieldSpec.hint);
-            }).bind(this));
+            });
         }
 
         this._editorGrid.attach(entry, 1, this._currentRow, 1, 1);
@@ -658,25 +648,25 @@ var OSMEditDialog = new Lang.Class({
         this._addOSMEditDeleteButton(fieldSpec);
 
         this._currentRow++;
-    },
+    }
 
-    _addOSMEditIntegerEntry: function(fieldSpec, value) {
+    _addOSMEditIntegerEntry(fieldSpec, value) {
         this._addOSMEditLabel(fieldSpec);
 
         let spinbutton = Gtk.SpinButton.new_with_range(0, 1e9, 1);
         spinbutton.value = value;
         spinbutton.numeric = true;
         spinbutton.hexpand = true;
-        spinbutton.connect('changed', (function() {
+        spinbutton.connect('changed', () => {
             this._osmObject.set_tag(fieldSpec.tag, spinbutton.text);
             this._nextButton.sensitive = true;
-        }).bind(this, fieldSpec.tag, spinbutton));
+        });
 
         if (fieldSpec.hint) {
             spinbutton.secondary_icon_name = 'dialog-information-symbolic';
-            spinbutton.connect('icon-press', (function(iconPos, event) {
+            spinbutton.connect('icon-press', (iconPos, event) => {
                 this._showHintPopover(spinbutton, fieldSpec.hint);
-            }).bind(this));
+            });
         }
 
         this._editorGrid.attach(spinbutton, 1, this._currentRow, 1, 1);
@@ -685,9 +675,9 @@ var OSMEditDialog = new Lang.Class({
 
         this._addOSMEditDeleteButton(fieldSpec);
         this._currentRow++;
-    },
+    }
 
-    _addOSMEditComboEntry: function(fieldSpec, value) {
+    _addOSMEditComboEntry(fieldSpec, value) {
         this._addOSMEditLabel(fieldSpec);
 
         let combobox = new Gtk.ComboBoxText();
@@ -697,10 +687,10 @@ var OSMEditDialog = new Lang.Class({
         });
         combobox.active_id = value;
         combobox.hexpand = true;
-        combobox.connect('changed', (function() {
-        this._osmObject.set_tag(fieldSpec.tag, combobox.active_id);
+        combobox.connect('changed', () => {
+            this._osmObject.set_tag(fieldSpec.tag, combobox.active_id);
             this._nextButton.sensitive = true;
-        }).bind(this, fieldSpec.tag, combobox));
+        });
 
         this._editorGrid.attach(combobox, 1, this._currentRow, 1, 1);
         combobox.show();
@@ -708,9 +698,9 @@ var OSMEditDialog = new Lang.Class({
 
         this._addOSMEditDeleteButton(fieldSpec);
         this._currentRow++;
-    },
+    }
 
-    _addOSMEditAddressEntry: function(fieldSpec, value) {
+    _addOSMEditAddressEntry(fieldSpec, value) {
         this._addOSMEditLabel(fieldSpec);
 
         let addr = new OSMEditAddress({ street: value[0],
@@ -732,10 +722,10 @@ var OSMEditDialog = new Lang.Class({
         addr.street.grab_focus();
         this._addOSMEditDeleteButton(fieldSpec);
         this._currentRow += rows;
-    },
+    }
 
     /* update visible items in the "Add Field" popover */
-    _updateAddFieldMenu: function() {
+    _updateAddFieldMenu() {
         /* clear old items */
         let children = this._addFieldPopoverGrid.get_children();
         let hasAllFields = true;
@@ -751,10 +741,10 @@ var OSMEditDialog = new Lang.Class({
             let hasValue = false;
 
             if (fieldSpec.subtags) {
-                fieldSpec.subtags.forEach((function(tag) {
+                fieldSpec.subtags.forEach((tag) => {
                     if (this._osmObject.get_tag(tag) !== null)
                         hasValue = true;
-                }).bind(this));
+                });
             } else {
                 hasValue = this._osmObject.get_tag(fieldSpec.tag) !== null;
             }
@@ -769,21 +759,21 @@ var OSMEditDialog = new Lang.Class({
                 button.get_style_context().add_class('flat');
                 button.get_child().halign = Gtk.Align.START;
 
-                button.connect('clicked', (function() {
+                button.connect('clicked', () => {
                     this._addFieldButton.active = false;
                     this._addOSMField(fieldSpec, '');
                     /* add a "placeholder" empty OSM tag to keep the add field
                      * menu updated, these tags will be filtered out if nothing
                      * is entered */
                     if (fieldSpec.subtags) {
-                        fieldSpec.subtags.forEach((function(tag) {
+                        fieldSpec.subtags.forEach((tag) => {
                             this._osmObject.set_tag(tag, '');
-                        }).bind(this));
+                        });
                     } else {
                         this._osmObject.set_tag(fieldSpec.tag, '');
                     }
                     this._updateAddFieldMenu();
-                }).bind(this));
+                });
 
                 hasAllFields = false;
                 this._addFieldPopoverGrid.add(button);
@@ -791,9 +781,9 @@ var OSMEditDialog = new Lang.Class({
         }
 
         this._addFieldButton.sensitive = !hasAllFields;
-    },
+    }
 
-    _addOSMField: function(fieldSpec, value) {
+    _addOSMField(fieldSpec, value) {
         switch (fieldSpec.type) {
         case EditFieldType.TEXT:
             this._addOSMEditTextEntry(fieldSpec, value);
@@ -808,9 +798,9 @@ var OSMEditDialog = new Lang.Class({
             this._addOSMEditAddressEntry(fieldSpec, value);
             break;
         }
-    },
+    }
 
-    _loadOSMData: function(osmObject) {
+    _loadOSMData(osmObject) {
         this._osmObject = osmObject;
 
         /* keeps track of the current insertion row in the grid for editing
