@@ -21,7 +21,7 @@
 
 const Clutter = imports.gi.Clutter;
 const Gdk = imports.gi.Gdk;
-const Lang = imports.lang;
+const GObject = imports.gi.GObject;
 const Mainloop = imports.mainloop;
 
 const Application = imports.application;
@@ -31,11 +31,10 @@ const MapMarker = imports.mapMarker;
 const Place = imports.place;
 const Utils = imports.utils;
 
-var TurnPointMarker = new Lang.Class({
-    Name: 'TurnPointMarker',
-    Extends: MapMarker.MapMarker,
+var TurnPointMarker = GObject.registerClass(
+class TurnPointMarker extends MapMarker.MapMarker {
 
-    _init: function(params) {
+    _init(params) {
         this._queryPoint = params.queryPoint;
         delete params.queryPoint;
 
@@ -62,14 +61,12 @@ var TurnPointMarker = new Lang.Class({
         params.place = new Place.Place({
             location: new Location.Location({ latitude: latitude,
                                               longitude: longitude }) });
-        this.parent(params);
+        super._init(params);
 
         let actor;
         if (this._queryPoint) {
             this.draggable = true;
-            this.connect('drag-finish', (function() {
-                this._onMarkerDrag();
-            }).bind(this));
+            this.connect('drag-finish', () => this._onMarkerDrag());
             actor = this._actorFromIconName(this._turnPoint.iconName, 0);
         } else {
             let color = this._getColor();
@@ -78,9 +75,9 @@ var TurnPointMarker = new Lang.Class({
                                             color);
         }
         this.add_actor(actor);
-    },
+    }
 
-    _getColor: function() {
+    _getColor() {
         /* Use the route color from the transit leg when representing part of
          * a transit trip, otherwise let the fallback functionallity of the
          * utility function use a GNOMEish blue color for turn-by-turn routing.
@@ -91,30 +88,30 @@ var TurnPointMarker = new Lang.Class({
                               green: Color.parseColor(color, 1, 93 / 255),
                               blue: Color.parseColor(color, 2, 155 / 255),
                               alpha: 255 });
-    },
+    }
 
     get anchor() {
         return { x: Math.floor(this.width / 2) - 1,
                  y: Math.floor(this.height / 2) - 1 };
-    },
+    }
 
-    goTo: function() {
+    goTo() {
         let view = this._mapView.view;
         let turnPointZoomLevel = 15;
 
         view.goto_animation_mode = Clutter.AnimationMode.LINEAR;
         view.goto_duration = 0;
 
-        Utils.once(view, 'animation-completed', (function() {
+        Utils.once(view, 'animation-completed', () => {
             view.zoom_level = turnPointZoomLevel;
             view.center_on(this.latitude,
                            this.longitude);
-        }).bind(this));
+        });
 
         view.go_to(this.latitude, this.longitude);
-    },
+    }
 
-    _onMarkerDrag: function() {
+    _onMarkerDrag() {
         let query = Application.routeQuery;
         let place = new Place.Place({
             location: new Location.Location({ latitude: this.latitude.toFixed(5),
